@@ -21,7 +21,7 @@
 #include "Python.h"
 #include <math.h>
 
-#define PYO_VERSION "1.0.0"
+#define PYO_VERSION "1.0.2"
 
 #ifndef __MYFLT_DEF
 #define __MYFLT_DEF
@@ -42,6 +42,7 @@
 #define TYPE_O_FIFFI "O|fiffi"
 #define TYPE_O_F "O|f"
 #define TYPE_O_FO "O|fO"
+#define TYPE_O_OIF "O|Oif"
 #define TYPE__OF "|Of"
 #define TYPE_O_FOO "O|fOO"
 #define TYPE_O_FIOO "O|fiOO"
@@ -132,6 +133,7 @@
 #define TYPE_O_FIFFI "O|diddi"
 #define TYPE_O_F "O|d"
 #define TYPE_O_FO "O|dO"
+#define TYPE_O_OIF "O|Oid"
 #define TYPE__OF "|Od"
 #define TYPE_O_FOO "O|dOO"
 #define TYPE_O_FIOO "O|diOO"
@@ -447,6 +449,7 @@ extern PyTypeObject M_ExpType;
 extern PyTypeObject FFTMainType;
 extern PyTypeObject FFTType;
 extern PyTypeObject IFFTType;
+extern PyTypeObject IFFTMatrixType;
 extern PyTypeObject CarToPolType;
 extern PyTypeObject PolToCarType;
 extern PyTypeObject FrameDeltaMainType;
@@ -515,6 +518,7 @@ extern PyTypeObject Particle2Type;
 extern PyTypeObject AtanTableType;
 extern PyTypeObject RawMidiType;
 extern PyTypeObject ResampleType;
+extern PyTypeObject ExprerType;
 extern PyTypeObject ExprType;
 extern PyTypeObject PadSynthTableType;
 extern PyTypeObject LogiMapType;
@@ -531,6 +535,17 @@ extern PyTypeObject MultiBandMainType;
 extern PyTypeObject MultiBandType;
 extern PyTypeObject M_DivType;
 extern PyTypeObject M_SubType;
+extern PyTypeObject BinauralerType;
+extern PyTypeObject BinauralType;
+extern PyTypeObject MMLMainType;
+extern PyTypeObject MMLType;
+extern PyTypeObject MMLFreqStreamType;
+extern PyTypeObject MMLAmpStreamType;
+extern PyTypeObject MMLDurStreamType;
+extern PyTypeObject MMLEndStreamType;
+extern PyTypeObject MMLXStreamType;
+extern PyTypeObject MMLYStreamType;
+extern PyTypeObject MMLZStreamType;
 
 /* Constants */
 #define E M_E
@@ -1344,6 +1359,13 @@ extern PyTypeObject M_SubType;
     } \
  \
     self->data[y][x] = val; \
+ \
+    if (x == 0 && y == 0) \
+        self->data[self->height][self->width] = self->data[y][x]; \
+    else if (x == 0) \
+        self->data[y][self->width] = self->data[y][x]; \
+    else if (y == 0) \
+        self->data[self->height][x] = self->data[y][x]; \
  \
     Py_INCREF(Py_None); \
     return Py_None; \
